==> haskell-indexed-profunctors-0.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-indexed-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 indexed-profunctors
version:              0.1
visibility:           public
id:                   indexed-profunctors-0.1-LR8UN1hkBPIJziflGEiYEw
key:                  indexed-profunctors-0.1-LR8UN1hkBPIJziflGEiYEw
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Adam Gundry, Andres Löh, Andrzej Rybczak, Oleg Grenrus
synopsis:             Utilities for indexed profunctors
description:
    This package contains basic definitions related to indexed profunctors.  These
    are primarily intended as internal utilities to support the @optics@ and
    @generic-lens@ package families.

category:             Data, Optics, Lenses, Profunctors
abi:                  90ad49b8a222525c7483fe8f45d6ca0f
exposed:              True
exposed-modules:      Data.Profunctor.Indexed
import-dirs:          /usr/lib/ghc-8.8.1/site-local/indexed-profunctors-0.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/indexed-profunctors-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/indexed-profunctors-0.1
hs-libraries:         HSindexed-profunctors-0.1-LR8UN1hkBPIJziflGEiYEw
depends:              base-4.13.0.0
haddock-interfaces:
    /usr/share/doc/haskell-indexed-profunctors/html/indexed-profunctors.haddock

haddock-html:         /usr/share/doc/haskell-indexed-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-indexed-profunctors-0.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-indexed-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 indexed-profunctors
version:              0.1
visibility:           public
id:                   indexed-profunctors-0.1-LhT6ov8AsxY9WVPX29xEKs
key:                  indexed-profunctors-0.1-LhT6ov8AsxY9WVPX29xEKs
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Adam Gundry, Andres Löh, Andrzej Rybczak, Oleg Grenrus
synopsis:             Utilities for indexed profunctors
description:
    This package contains basic definitions related to indexed profunctors.  These
    are primarily intended as internal utilities to support the @optics@ and
    @generic-lens@ package families.

category:             Data, Optics, Lenses, Profunctors
abi:                  d5067e57bbd0eb57b648ee9987d81343
exposed:              True
exposed-modules:      Data.Profunctor.Indexed
import-dirs:          /usr/lib/ghc-8.10.1/site-local/indexed-profunctors-0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/indexed-profunctors-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/indexed-profunctors-0.1
hs-libraries:         HSindexed-profunctors-0.1-LhT6ov8AsxY9WVPX29xEKs
depends:              base-4.14.0.0
haddock-interfaces:
    /usr/share/doc/haskell-indexed-profunctors/html/indexed-profunctors.haddock

haddock-html:         /usr/share/doc/haskell-indexed-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
